@@ -17,8 +17,8 @@ import numpy as np
 import tensorflow as tf
 from tensorflow import keras
 
+from keras_cv import bounding_box
 from keras_cv.metrics import COCOMeanAveragePrecision
-from keras_cv.utils import bounding_box as bounding_box_utils
 
 
 class COCOMeanAveragePrecisionTest(tf.test.TestCase):
@@ -208,7 +208,7 @@ class COCOMeanAveragePrecisionTest(tf.test.TestCase):
         y_true = tf.constant([[[0, 0, 100, 100, 1]]], dtype=tf.float64)
         y_pred = tf.constant([[[0, 50, 100, 150, 1, 1.0]]], dtype=tf.float32)
 
-        y_true = bounding_box_utils.pad_bounding_box_batch_to_shape(y_true, (1, 20, 5))
+        y_true = bounding_box.pad_batch_to_shape(y_true, (1, 20, 5))
 
         metric = COCOMeanAveragePrecision(
             iou_thresholds=[0.15],
