@@ -17,8 +17,8 @@ import tensorflow as tf
 import tensorflow.keras as keras
 import tensorflow.keras.initializers as initializers
 
+from keras_cv import bounding_box
 from keras_cv.metrics.coco import utils
-from keras_cv.utils import bounding_box
 from keras_cv.utils import iou as iou_lib
 
 
@@ -54,7 +54,7 @@ class COCORecall(keras.metrics.Metric):
     account for this, you may either pass a `tf.RaggedTensor`, or pad Tensors
     with `-1`s to indicate unused boxes.  A utility function to perform this
     padding is available at
-    `keras_cv.utils.bounding_box.pad_bounding_box_batch_to_shape`.
+    `keras_cv.bounding_box.pad_batch_to_shape`.
 
     ```python
     coco_recall = keras_cv.metrics.COCORecall(
@@ -82,11 +82,10 @@ class COCORecall(keras.metrics.Metric):
     ):
         super().__init__(**kwargs)
         # Initialize parameter values
-
         iou_thresholds = iou_thresholds or [x / 100.0 for x in range(50, 100, 5)]
+
         self.iou_thresholds = iou_thresholds
         self.class_ids = class_ids
-
         self.area_range = area_range
         self.max_detections = max_detections
 
@@ -215,3 +214,15 @@ class COCORecall(keras.metrics.Metric):
             tf.math.reduce_sum(recalls, axis=-1) / n_present_categories
         )
         return tf.math.reduce_mean(recalls_per_threshold)
+
+    def get_config(self):
+        config = super().get_config()
+        config.update(
+            {
+                "class_ids": self.class_ids,
+                "iou_thresholds": self.iou_thresholds,
+                "area_range": self.area_range,
+                "max_detections": self.max_detections,
+            }
+        )
+        return config
